module StaticMaps
  module Params
    extend self

    BASE_URL = 'http://maps.googleapis.com/maps/api/staticmap'

    DEFAULTS = {
      :visual_refresh => true,                    # Use new color scheme
      :center         => 'Stan,Mountain View,CA', # GooglePlex's Stan
      :size           => '640x640',               # Max size (free API)
      :sensor         => false,                   # No sensor
      :zoom           => 16                       # No sensor
    }.freeze

    ALLOWED = [:visual_refresh, :center, :size, :sensor, :language, :region,
               :zoom, :scale, :markers, :format, :maptype, :visible].freeze

    def filter_allowed(params)
      DEFAULTS.merge params.select {|k,v| ALLOWED.include? k}
    end

    def validated_params(params)
      {}.tap do |p|
        filter_allowed(params).map {|k,v| p[k] = Validations::validate(k,v)}
      end
    end

    def concat_params(params)
      [].tap do |url|
        validated_params(params).each_with_index do |(k,v),i|
          url << "#{i==0 ? '?' : '&'}#{k}=#{v}"
        end
      end.join('')
    end

    def url_safe(str)
      str.strip.gsub(/[ |]+/,' ' => '+', '|' => '%7C')
    end

    def build_url(params)
      url_safe(BASE_URL + concat_params(params))
    end

  end
end

